Constants
- COMMONMETA_
FIXTURE_ JOURNAL_ ARTICLE - Embedded Commonmeta journal article fixture.
- COMMONMETA_
SCHEMA_ V1_ 0RC1 - Embedded Commonmeta schema v1.0rc1.
- COMMONMETA_
SCHEMA_ V1_ 0RC2 - Embedded Commonmeta schema v1.0rc2.
Statics
- FIXTURES
- The complete tree of Commonmeta conformance fixtures, embedded at compile
time. Organized as
<format>/<name>.<ext>(e.g.commonmeta/journal_article.json,crossref/journal_article.json,orcid/0000-0002-0068-716X.xml).
Functions
- fixture
- Return an embedded Commonmeta fixture by name.
- fixture_
bytes - Return an embedded fixture’s raw bytes by relative path, e.g.
fixture_bytes("commonmeta/journal_article.json"). - fixture_
str - Return an embedded fixture’s UTF-8 contents by relative path, e.g.
fixture_str("crossref/journal_article.json"). ReturnsNoneif the file is absent or not valid UTF-8. - schema
- Return an embedded schema by Commonmeta version string.